function out=calc_bragg_exact(x,R0,sigma,epsilon);

% Date written: September 2001
% Revisions:    rev. 2 (Nov. 13, 2001): no table look-up
%
% Author:	    Thomas Bortfeld, MGH Boston
% Keywords:	    Bragg Peak, Analytical Modeling
% Description:	Calculate Bragg Peak using [1].
%               This calculation is for water, eq. 29 of [1].
% References:	[1] T. Bortfeld, Med. Phys. 24(12), 2024-2033, 1997

z = (x-R0)/sigma;
out = z;    % make 'out' an array of the same dimension as z

for i=1:length(z)
    out(i) = 65.*(cyl_gauss(-0.565,z(i))+sigma*(0.001394+epsilon/R0)*cyl_gauss(-1.565,z(i)));
    % the 0.65 is 100.*0.8/1.23. (cyl_gauss(-0.565,0)=1.23, bragg(R0)=0.8)
end


% bragg peak un-normalized:
% out = sigma^0.565 / (1.+0.012*R0) * (11.26/sigma*cyl_gauss1(index)+(0.157+11.26*epsilon/R0)*cyl_gauss2(index));
