function out=hyperg(a,b,z);

% Date written:	November 13, 2001
% Revisions:
% Author:	Thomas Bortfeld, MGH Boston
% Keywords:	special functions, degenerate hypergeometric function
% Description:	Taylor series expansion of the degenerate hypergeometric
%		function Phi(alpha,gamma,z) (cf. [1], section 
%		9.210), useful for small values of |z|. The value of eps
%		can be adjusted to calculate more or less significant 
%		digits.
% References:	[1] Gradshteyn & Ryzhik; Table of integrals, series and 
%		products; Academic Press; London; 1980.	 

epsi = 0.00001;

hypergeom = 1.;
term_i = 1.;

for i=1:1000
    term_i = term_i * (a+i-1.)*z/(b+i-1.)/i;
    hypergeom = hypergeom + term_i;
    if(abs(term_i) <= epsi*hypergeom) 
        out = hypergeom;
        return;
    end    
end

error('No convergence in HYPERG !!!');
